@@ -64,7 +64,3 @@ generics::forecast
 #' @importFrom distributional hilo
 #' @export
 distributional::hilo
-
-#' @importFrom distributional guide_level
-#' @export
-distributional::guide_level
\ No newline at end of file
